Interface: ArcElement | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ArcElement<T, O>

## # Type parameters

Name | Type
--- | ---
`T` | extends `ArcProps` = `ArcProps`
`O` | extends `ArcOptions` = `ArcOptions`

## # Hierarchy

- `Element`<`T`, `O`>

- `VisualElement`

  ↳ `ArcElement`

## # Properties

### # active

• `Readonly` active: `boolean`

#### # Inherited from

Element.active

#### # Defined in

element.d.ts:7
(opens new window)

### # options

• `Readonly` options: `O`

#### # Inherited from

Element.options

#### # Defined in

element.d.ts:8
(opens new window)

### # x

• `Readonly` x: `number`

#### # Inherited from

Element.x

#### # Defined in

element.d.ts:5
(opens new window)

### # y

• `Readonly` y: `number`

#### # Inherited from

Element.y

#### # Defined in

element.d.ts:6
(opens new window)

## # Methods

### # draw

▸ draw(`ctx`, `area?`): `void`

#### # Parameters

Name | Type
--- | ---
`ctx` | `CanvasRenderingContext2D`
`area?` | `ChartArea`

#### # Returns

`void`

#### # Inherited from

VisualElement.draw

#### # Defined in

index.esm.d.ts:1685
(opens new window)

### # getCenterPoint

▸ getCenterPoint(`useFinalPosition?`): `Object`

#### # Parameters

Name | Type
--- | ---
`useFinalPosition?` | `boolean`

#### # Returns

`Object`

Name | Type
--- | ---
`x` | `number`
`y` | `number`

#### # Inherited from

VisualElement.getCenterPoint

#### # Defined in

index.esm.d.ts:1689
(opens new window)

### # getProps

▸ getProps<`P`>(`props`, `final?`): `Pick`<`T`, `P`[`number`]>

#### # Type parameters

Name | Type
--- | ---
`P` | extends keyof `T`[]

#### # Parameters

Name | Type
--- | ---
`props` | `P`
`final?` | `boolean`

#### # Returns

`Pick`<`T`, `P`[`number`]>

#### # Inherited from

Element.getProps

#### # Defined in

element.d.ts:12
(opens new window)

### # getRange

▸ `Optional` getRange(`axis`): `number`

#### # Parameters

Name | Type
--- | ---
`axis` | `"x"` | `"y"`

#### # Returns

`number`

#### # Inherited from

VisualElement.getRange

#### # Defined in

index.esm.d.ts:1690
(opens new window)

### # hasValue

▸ hasValue(): `boolean`

#### # Returns

`boolean`

#### # Inherited from

Element.hasValue

#### # Defined in

element.d.ts:11
(opens new window)

### # inRange

▸ inRange(`mouseX`, `mouseY`, `useFinalPosition?`): `boolean`

#### # Parameters

Name | Type
--- | ---
`mouseX` | `number`
`mouseY` | `number`
`useFinalPosition?` | `boolean`

#### # Returns

`boolean`

#### # Inherited from

VisualElement.inRange

#### # Defined in

index.esm.d.ts:1686
(opens new window)

### # inXRange

▸ inXRange(`mouseX`, `useFinalPosition?`): `boolean`

#### # Parameters

Name | Type
--- | ---
`mouseX` | `number`
`useFinalPosition?` | `boolean`

#### # Returns

`boolean`

#### # Inherited from

VisualElement.inXRange

#### # Defined in

index.esm.d.ts:1687
(opens new window)

### # inYRange

▸ inYRange(`mouseY`, `useFinalPosition?`): `boolean`

#### # Parameters

Name | Type
--- | ---
`mouseY` | `number`
`useFinalPosition?` | `boolean`

#### # Returns

`boolean`

#### # Inherited from

VisualElement.inYRange

#### # Defined in

index.esm.d.ts:1688
(opens new window)

### # tooltipPosition

▸ tooltipPosition(`useFinalPosition?`): `Point`

#### # Parameters

Name | Type
--- | ---
`useFinalPosition?` | `boolean`

#### # Returns

`Point`

#### # Inherited from

Element.tooltipPosition

#### # Defined in

element.d.ts:10
(opens new window)